/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 *
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli;

import org.ow2.petals.cli.api.shell.ShellExtension;
import org.ow2.petals.cli.pref.PreferencesImpl;
import org.ow2.petals.cli.shell.command.Connect;
import org.ow2.petals.cli.shell.extension.HttpServerShellExtension;
import org.ow2.petals.cli.shell.extension.PetalsAdminShellExtension;

/**
 * Start the Petals ESB Command Line Interface.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class Main extends AbstractMain {

    /**
     * Header part of the usage message
     */
    public final static String USAGE_HEADER = "Petals ESB Command Line Interface";

    /**
     * The base used to build the shell prompt
     */
    public static final String PROMPT_BASE = "petals-cli";

    /**
     * Main entry point to run Petals ESB CLI
     */
    public static void main(final String[] args) {
        final Main main = new Main();
        final PreferencesImpl preferences = new PreferencesImpl();
        System.exit(main.run(args, preferences,
                new ShellExtension[] { new HttpServerShellExtension(preferences), new PetalsAdminShellExtension() }));
    }

    public Main() {
        super(new Connect());
    }

    @Override
    protected String getUsageHeader() {
        return USAGE_HEADER;
    }

    @Override
    protected String getPromptBase() {
        return PROMPT_BASE;
    }
}
