/**
 * Copyright (c) 2015-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import org.apache.commons.cli.Option;
import org.ow2.petals.admin.api.artifact.Component.ComponentType;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.ServiceUnit;
import org.ow2.petals.admin.api.artifact.SharedLibrary;

import jline.console.completer.Completer;
import jline.console.completer.StringsCompleter;

/**
 * A command having parameters associated to an artifact type must implement this interface to define its option
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface ArtifactTypeBasedCommand {

    public static final String TYPE_SHORT_OPTION = "t";

    public final String TYPE_LONG_OPTION = "type";

    public static final Option TYPE_OPTION = Option.builder(TYPE_SHORT_OPTION).required(false).longOpt(TYPE_LONG_OPTION)
            .desc("<artifact-type> is one of the following optional values: SL, BC, SE, SA, SU, used to restrict artifacts matching other parameters.")
            .numberOfArgs(1).argName("artifact-type").build();

    public final Completer ARTIFACT_TYPE_COMPLETER = new StringsCompleter(SharedLibrary.TYPE,
            ComponentType.BC.toString(), ComponentType.SE.toString(), ServiceAssembly.TYPE, ServiceUnit.TYPE);

}
