/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import org.ow2.petals.admin.api.ContainerAdministration;
import org.ow2.petals.admin.api.exception.DuplicatedServiceException;
import org.ow2.petals.admin.api.exception.MissingServiceException;
import org.ow2.petals.cli.api.command.exception.CommandException;

/**
 * This command print version info of a remote petals ESB instance.
 * 
 * @author Sebastien Andre - EBM WebSourcing
 */
public class Version extends AbstractPetalsCliCommand {

    public Version() {
        super();
        this.setUsage("usage: version");
        this.setDescription("Print version informations about petals container");
    }

    @Override
    public void doExecute(final String[] args) throws CommandException {
        try {
            final ContainerAdministration containerAdministration = getAdmin().newContainerAdministration();
            final String version = containerAdministration.getSystemInfo();
            this.getShell().getPrintStream().println(version);
        } catch (final DuplicatedServiceException e) {
            throw new CommandException(this, e);
        } catch (final MissingServiceException e) {
            throw new CommandException(this, e);
        } catch (final Exception e) {
            throw new CommandException(this, e);
        }

    }

}
