/**
 * Copyright (c) 2014-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.completer;

import java.util.Collection;

import jline.console.completer.StringsCompleter;

import org.ow2.petals.admin.api.ArtifactAdministration;
import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;

/**
 * Base class for completer about filtered artifact names
 * 
 * @author Christophe DENEUX
 * 
 */
public abstract class FileteredArtifactNameCompleter extends StringsCompleter {

    public FileteredArtifactNameCompleter(final ArtifactAdministration artifactAdministration) {
        super();

        assert artifactAdministration != null;

        final Collection<String> strings = this.getStrings();
        try {
            for (final Artifact artifact : artifactAdministration.listArtifacts()) {
                if (this.acceptArtifact(artifact)) {
                    strings.add(artifact.getName());
                }
            }
        } catch (final ArtifactAdministrationException e) {
            // NOP: if an error occurs no container name will be proposed
        }
    }

    /**
     * Accept the artifact to be added as result of the completer
     * 
     * @param artifact
     *            The artifact to accept
     * @return <code>true</code> to accept the artifact, <code>false</code> to reject it.
     */
    protected abstract boolean acceptArtifact(final Artifact artifact);
}
