/**
 * Copyright (c) 2014-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli;

import static org.junit.Assert.assertTrue;

import org.ow2.petals.cli.api.command.ConnectionCommand;
import org.ow2.petals.cli.api.command.DisconnectionCommand;
import org.ow2.petals.cli.base.junit.AbstractEmbeddedCommandsTest;
import org.ow2.petals.cli.command.Exit;
import org.ow2.petals.cli.command.Help;
import org.ow2.petals.cli.command.Load;
import org.ow2.petals.cli.command.Print;
import org.ow2.petals.cli.command.Pwd;
import org.ow2.petals.cli.command.Set;
import org.ow2.petals.cli.command.SystemCall;
import org.ow2.petals.cli.shell.command.CheckSSLHandshake;
import org.ow2.petals.cli.shell.command.Connect;
import org.ow2.petals.cli.shell.command.Deploy;
import org.ow2.petals.cli.shell.command.Disconnect;
import org.ow2.petals.cli.shell.command.ListArtifacts;
import org.ow2.petals.cli.shell.command.ListEndpoints;
import org.ow2.petals.cli.shell.command.LoggerSet;
import org.ow2.petals.cli.shell.command.Loggers;
import org.ow2.petals.cli.shell.command.MoveContainer;
import org.ow2.petals.cli.shell.command.PropertiesList;
import org.ow2.petals.cli.shell.command.ReloadConfiguration;
import org.ow2.petals.cli.shell.command.Show;
import org.ow2.petals.cli.shell.command.StartArtifact;
import org.ow2.petals.cli.shell.command.Stop;
import org.ow2.petals.cli.shell.command.StopArtifact;
import org.ow2.petals.cli.shell.command.TopologyList;
import org.ow2.petals.cli.shell.command.Undeploy;
import org.ow2.petals.cli.shell.command.Version;

/**
 * A unit test to check that Petals ESB CLI embeds all its commands, and only the expected commands.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class EmbeddedCommandsTest extends AbstractEmbeddedCommandsTest {

    public final static Class<?>[] EXPECTED_COMMANDS = new Class[] { CheckSSLHandshake.class, Connect.class,
            Deploy.class, Disconnect.class, Exit.class, Help.class, ListArtifacts.class, ListEndpoints.class,
            Load.class, LoggerSet.class, Loggers.class, MoveContainer.class, Print.class, PropertiesList.class,
            Pwd.class, ReloadConfiguration.class, Set.class, Show.class, StartArtifact.class, Stop.class,
            StopArtifact.class, SystemCall.class, TopologyList.class, Undeploy.class, Version.class };

    @Override
    protected Class<?>[] getExpectedCommands() {
        return EXPECTED_COMMANDS;
    }

    @Override
    protected void assertConnectionCommand(final ConnectionCommand command) {
        assertTrue(command instanceof Connect);
    }

    @Override
    protected void assertDisconnectionCommand(final DisconnectionCommand command) {
        assertTrue(command instanceof Disconnect);
    }

}
