/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import static org.junit.Assert.assertNotNull;

import java.net.URL;

import org.junit.After;
import org.junit.Before;
import org.junit.Rule;
import org.junit.contrib.java.lang.system.ProvideSystemProperty;
import org.ow2.petals.admin.api.ArtifactAdministration;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ContainerAdministrationException;

/**
 * Abstract class with useful method for artifact command test.
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public abstract class AbstractArtifactCommandTest extends AbstractConnectedShellTest {

    protected final static String COMPONENT_FILENAME = "jbi-component-soap.zip";

    protected final static URL COMPONENT_URL = Thread.currentThread().getContextClassLoader()
            .getResource(COMPONENT_FILENAME);

    protected final static String COMPONENT_ID = "petals-bc-soap-provide";

    protected final static String SA_PERMISSION_FILENAME = "sa-permission.zip";

    protected final static URL SA_URL = Thread.currentThread().getContextClassLoader()
            .getResource(SA_PERMISSION_FILENAME);

    protected final static String SA_SOAPID_FILENAME = "sa-soapid.zip";

    protected final static URL SA_SOAP_ID_URL = Thread.currentThread().getContextClassLoader()
            .getResource(SA_SOAPID_FILENAME);

    protected final static String SL_FILENAME = "petals-sl-mysql-5.1.5.zip";

    protected final static String SL_VERSION = "5.1.5";

    protected final URL slURL = Thread.currentThread().getContextClassLoader().getResource(SL_FILENAME);

    protected final static String SL2_FILENAME = "petals-sl-mysql-4.1.5.zip";

    protected final static String SL2_VERSION = "4.1.5";

    protected final URL sl2URL = Thread.currentThread().getContextClassLoader().getResource(SL2_FILENAME);

    @Before
    public void beforeTest() {
        assertNotNull("Component archive '" + COMPONENT_FILENAME + "' not found !", COMPONENT_URL);
        assertNotNull("SA archive '" + SA_PERMISSION_FILENAME + "' not found !", SA_URL);
        assertNotNull("SA archive '" + SA_SOAPID_FILENAME + "' not found !", SA_SOAP_ID_URL);
        assertNotNull("SL archive '" + SL_FILENAME + "' not found !", this.slURL);
        assertNotNull("SL archive '" + SL2_FILENAME + "' not found !", this.sl2URL);
    }

    /**
     * Registration of PAX URL handler
     */
    @Rule
    public final ProvideSystemProperty provideSystemProperty = new ProvideSystemProperty("java.protocol.handler.pkgs",
            "org.ops4j.pax.url");

    @Before
    public void setUpEnvironment() throws ContainerAdministrationException {
        connectSingleton();
    }

    @After
    public void undeployArtifacts() throws ArtifactAdministrationException {
        getArtifactAdmin().stopAndUndeployAllArtifacts();
    }

    protected ArtifactAdministration getArtifactAdmin() {
        return api.getSingleton().newArtifactAdministration();
    }

    /**
     * Deploy specified artifacts.
     * 
     * @param urls
     * @throws ArtifactAdministrationException
     */
    protected void deployStartArtifact(URL... urls) throws ArtifactAdministrationException {
        final ArtifactAdministration artifactAdministration = getArtifactAdmin();
        for (final URL url : urls) {
            artifactAdministration.deployAndStartArtifact(url, false);
        }
    }
}
