/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import org.junit.Rule;
import org.junit.Test;
import org.ow2.petals.admin.junit.PetalsAdministrationApi;
import org.ow2.petals.admin.junit.utils.SystemInfoUtils;
import org.ow2.petals.cli.api.command.Command;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.ConnectionRequiredException;
import org.ow2.petals.cli.base.junit.shell.StringStreamShell;
import org.ow2.petals.cli.connection.AuthenticatedConnectionParametersImpl;
import org.ow2.petals.cli.shell.extension.PetalsAdminShellExtension;

/**
 *
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 *
 */
public class VersionTest extends AbstractShellTest {

    @Rule
    final public PetalsAdministrationApi adminApi = new PetalsAdministrationApi();

    /**
     * Test that the command usage is defined
     */
    @Test
    public void usage() {
        final Version command = new Version();
        final String usage = command.getUsage();
        assertNotNull("Command usage null", usage);
        assertFalse("Command usage empty", usage.isEmpty());
        assertTrue("'usage' is missing at the begining of the command usage", usage.startsWith("usage"));
        assertTrue("The command name is missing in the command usage", usage.contains(command.getName()));
    }

    /**
     * <p>
     * Test of the command "version" when a connection is established before to run the command.
     * </p>
     * <p>
     * Expected results: no error occurs and the system information are correctly returned
     * </p>
     */
    @Test
    public void testExecute() throws Exception {

        // Set the environment
        this.adminApi.registerNullDomain();
        this.adminApi.registerSystemInfo(SystemInfoUtils.SYSTEM_INFO_EXAMPLE);
        final StringStreamShell shell = new StringStreamShell();
        shell.addExtension(new PetalsAdminShellExtension());
        final Connect connect = new Connect();
        connect.setShell(shell);
        connect.connect(new AuthenticatedConnectionParametersImpl("localhost", 7700, "petals", "petals", null), false);

        // Execute command
        final Version command = new Version();
        command.setShell(shell);
        command.execute(new String[] {});

        // Assertions
        assertTrue("An error message is printed", shell.getError().isEmpty());
        assertTrue("Unexpected output", shell.getOutput().matches(SystemInfoUtils.SYSTEM_INFO_EXAMPLE + "\r?\n"));
    }

    /**
     * <p>
     * Test of the command "version" when no connection is established to run the command.
     * </p>
     * <p>
     * Expected results: an error occurs about the connection not established.
     * </p>
     */
    @Test(expected = ConnectionRequiredException.class)
    public void executeNotConnected() throws CommandException {

        final Command command = new Version();
        command.setShell(new StringStreamShell());

        command.execute(new String[] {});
    }
}
